@@ -423,9 +423,36 @@ class Client:
         )
         request.raise_for_status()
 
-    def get_imports(self):
+    def get_imports(
+        self,
+        device_id: Optional[str] = None,
+        start: Optional[datetime.datetime] = None,
+        end: Optional[datetime.datetime] = None,
+        data_start: Optional[datetime.datetime] = None,
+        data_end: Optional[datetime.datetime] = None,
+        include_deleted: bool = False,
+    ):
+        """
+        Fetches imports.
+
+        :param device_id: The id of the device associated with the import.
+        :param start: Optional filter by import start time.
+        :param end: Optional filter by import end time.
+        :param data_start: Optional filter by data start time.
+        :param data_end: Optional filter by data end time.
+        :param include_deleted: Include deleted imports.
+        """
+        all_params = {
+            "deviceId": device_id,
+            "start": start.astimezone().isoformat() if start else None,
+            "end": end.astimezone().isoformat() if end else None,
+            "dataStart": data_start.astimezone().isoformat() if data_start else None,
+            "dataEnd": data_end.astimezone().isoformat() if data_end else None,
+            "includeDeleted": include_deleted,
+        }
         response = requests.get(
             self.__url__("/v1/data/imports"),
+            params={k: v for k, v in all_params.items() if v},
             headers=self.__headers,
         )
         json = json_or_raise(response)
